#
# spec file for package python-Cerberus
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define	skip_python2	1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Cerberus
Version:        1.3.5
Release:        2.3
Summary:        Extensible schema and data validation tool for Python dictionaries
License:        ISC
Group:          Development/Languages/Python
URL:            https://github.com/nicolaiarocci/cerberus
Source:         https://github.com/pyeve/cerberus/archive/refs/tags/%{version}.tar.gz#/cerberus-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION tests
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytest-benchmark}
# /SECTION
BuildRequires:  fdupes
BuildArch:      noarch

%python_subpackages

%description
Cerberus provides type checking and other base functionality out of the box and
is designed to be non-blocking and extensible, allowing for custom
validation.

%prep
%setup -q -n cerberus-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst UPGRADING.rst AUTHORS
%license LICENSE
%{python_sitelib}/*

%changelog
* Fri Aug 18 2023 Martin Schreiner <martin.schreiner@suse.com>
- Spec source changed from PyPI to GitHub since the PyPI tarball no
  longer includes the test suite.
- Update from 1.3.2 to 1.3.5.
- Changes from 1.3.5:
  * Support for Python 3.10 & 3.11
  * The HTML documentation uses the furo theme
  * *of rules are skipped for None values
  * Validations of mappings would raise an exception when the field’s
    rules were provided as reference to a registry item
  * Various minor improvements of the documentation
- Changes from 1.3.4:
  * Reverts the unsatisfying fix for #557
    Instead a RuntimeError is thrown when Python is running with
    optimization level 2
- Changes from 1.3.3:
  * Adds a benchmark to observe overall performance between code
    changes
  * Adds support for Python 3.9
  * The Continuous Integration now runs on GitHub Actions
  * Fixed unresolved registry references when getting a constraint for
    an error
  * Fixed crash when submitting non-hashable values to allowed
  * Fixed schema validation for rules specifications with space
  * Replaced deprecated rule name validator with check_with in the
    docs
  * Use the UnconcernedValidator when the Python interpreter is
    executed with an optimization flag
  * Several fixes and refinements of the docs
* Thu Oct 13 2022 Dirk Müller <dmueller@suse.com>
- use https for url
* Sun Aug 14 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Disable Python2 to fix 15.3 build.
* Mon Jun 29 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not disable py2 build for Leap
- Use pytest directly, pytest-runner is deprecated upstream
* Sat Jun 20 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1121858)
* Wed Jun  3 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- Disable Python 2 build, dependencies do not resolve.
* Tue Nov 12 2019 Steve Kowalik <steven.kowalik@suse.com>
- Update to version 1.3.2:
  New
  - Support for Python 3.8
  Fixed
  - Fixed the message of the BasicErrorHandler for an invalid amount of items (#505)
  - Added setuptools as dependency to the package metadata (#499)
  - The CHANGES.rst document is properly included in the package (#493)
  Improved
  - Docs: Examples were added for the min- and maxlength rules. (#509)
* Sat May 11 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.3.1:
  Fixed
  - Fixed the expansion of the deprecated rule names ``keyschema`` and
  ``valueschema`` (`#482`_)
  - ``*of_``-typesavers properly expand rule names containing ``_`` (`#484`_)
  Improved
  - Add ``maintainer`` and ``maintainer_email`` to setup.py (`#481`_)
  - Add ``project_urls`` to setup.py (`#480`_)
  - Don't ignore all exceptions during coercions for nullable fields. If a
  - Coercion raises an exception for a nullable field where the field is not
  ``None`` the validation now fails. (`#490`_)
* Tue Apr 30 2019 Michael Vetter mvetter@suse.com
- Update to 1.3:
  New:
  * Add require_all rule and validator argument (#417)
  * The contains rule (#358)
  * All fields that are defined as readonly are removed from a document when a validator has the purge_readonly flag set to True (#240)
  * The validator rule is renamed to check_with. The old name is deprecated and will not be available in the next major release of Cerberus (#405)
  * The rules keyschema and valueschema are renamed to keysrules and valuesrules; the old names are deprecated and will not be available in the next major release of Cerbers (#385)
  * The meta pseudo-rule can be used to store arbitrary application data related to a field in a schema
  * Python 3.7 officially supported (#451)
  * Python 2.6 and 3.3 are no longer supported
  Fixed:
  * Fix test test_{default,default_setter}_none_nonnullable (#435)
  * Normalization rules defined within the items rule are applied (#361)
  * Defaults are applied to undefined fields from an allow_unknown definition (#310)
  * The forbidden value now handles any input type (#449)
  * The allowed rule will not be evaluated on fields that have a legit None value (#454)
  * If the cerberus distribution cannot not be found, the version is set to the value unknown (#472)
  Improved:
  * Suppress DeprecationWarning about collections.abc (#451)
  * Omit warning when no schema for meta rule constraint is available (#425)
  * Reformat code to match Black code-style (#402)
  * Perform lint checks and fixes on staged files, as a pre-commit hook (#402)
  * Change allowed rule to use containers instead of lists (#384)
  * Remove Registry from top level namespace (#354)
  * Check the empty rule against values of type Sized
  * Various micro optimizations and 'safety belts' that were inspired by adding type annotations to a branch of the code base
  * Update docs
* Tue Jan 15 2019 Michael Vetter <mvetter@suse.com>
- Update to 1.2:
  * New: docs: Add note that normalization cannot be applied within an *of-rule. (Frank Sachsenheim)
  * New: Add the ability to query for a type of error in an error tree. (Frank Sachsenheim)
  * New: Add errors.MAPPING_SCHEMA on errors within subdocuments. (Frank Sachsenheim)
  * New: Support for Types Definitions, which allow quick types check on the fly. (Frank Sachsenheim)
  * Fix: Simplify the tests with Docker by using a volume for tox environments. (Frank Sachsenheim)
  * Fix: Schema registries do not work on dict fields. Closes :issue:`318`. (Frank Sachsenheim)
  * Fix: Need to drop some rules when empty is allowed. Closes :issue:`326`. (Frank Sachsenheim)
  * Fix: typo in README (Christian Hogan)
  * Fix: Make purge_unknown and allow_unknown play nice together. Closes :issue:`324`. (Audric Schiltknecht)
  * Fix: API reference lacks generated content. Closes :issue:`281`. (Frank Sachsenheim)
  * Fix: readonly works properly just in the first validation. Closes :issue:`311`. (Frank Sachsenheim)
  * Fix: coerce ignores nullable: True. Closes :issue:`269`. (Frank Sachsenheim)
  * Fix: A dependency is not considered satisfied if it has a null value. Closes :issue:`305`. (Frank Sachsenheim)
  * Override UnvalidatedSchema.copy. (Peter Demin)
  * Fix: README link. (Gabriel Wainer)
  * Fix: Regression: allow_unknown causes dictionary validation to fail with a KeyError. Closes :issue:`302`. (Frank Sachsenheim)
  * Fix: Error when setting fields as tuples instead of lists. Closes :issue:`271`. (Sebastian Rajo)
  * Fix: Correctly handle nested logic and group errors. Closes :issue:`278` and :issue:`299`. (Kornelijus Survila)
  * CI: Reactivate testing on PyPy3. (Frank Sachsenheim)
* Mon Jan  7 2019 ms@suse.com
- Submission to SUSE:SLE-15:Update
  This commit tracks the submission for fate#326575
  and bsc#1103542
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of description.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Aug 14 2018 ms@suse.com
- Submission to SUSE:SLE-12-SP3:Update:PubClouds
  This commit tracks the submission for fate#326575
  and bsc#1103542
* Tue Feb  6 2018 sebix+novell.com@sebix.at
- initial package for version 1.1
